@@ -734,7 +734,7 @@ def rolling_allocation(f, X, n=252, s=63, ret=True, drift=True, filtering_thresh
     return portfolio, w_mat
 
 
-def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True, ensembling_model = 'mean',  **kwargs):
+def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=True, ensembling_model = 'mean', period = 252, **kwargs):
     assert len(w_mat_predictors_list) > 1
     X = pd.DataFrame(X).fillna(method='ffill')
     if ret:
@@ -743,15 +743,21 @@ def rolling_ensembling(X, w_mat_predictors_list, w_mat_target, n=252, s=63,ret=T
         X_ = X
 
     if ensembling_model == 'mean':
+        index_tmp = w_mat_predictors_list[0].index
+        columns_tmp = w_mat_predictors_list[0].columns
         to_np = lambda my_df : my_df.values
         w_mat_predictors_list = list(map(to_np, w_mat_predictors_list))
-        tt_arrayy = np.hstack(np.array(w_mat_predictors_list))
-
-        w_mat = None
-        portfolio = None
+        np_mean_weights = None
+        for np_weights in w_mat_predictors_list:
+            if np_mean_weights is None :
+                np_mean_weights = np_weights
+            else :
+                np_mean_weights = np_mean_weights + np_weights
+        np_mean_weights = np_mean_weights/len(w_mat_predictors_list)
+        w_mat = pd.DataFrame(data = np_mean_weights,index=index_tmp, columns=columns_tmp)
+        portfolio = np.cumprod(np.prod(X_ * w_mat.values + 1, axis=1))
         return portfolio, w_mat
     else:
-
         to_apply = lambda my_df : pd.DataFrame(my_df).fillna(0)
         w_mat_predictors_list = list(map(to_apply, w_mat_predictors_list))
 
